read_events_compumedics: Read a stages export from Compumedics software in .txt format.
Description
Read a stages export from Compumedics software in .txt format.
Usage
read_events_compumedics(txt, startTime)
Value
A dataframe of stages.
Arguments
- txt
txt file path.
- startTime
Character string or date object of the hypnogram start.